# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FEATQUERY_METADATA = Metadata(
    id="48d3bb328fb85a7ab5b9bd0b9f9cd3f9f25fc4cc.boutiques",
    name="featquery",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FeatqueryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `featquery(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    query_report: OutputPathType
    """Generated query report file"""


def featquery(
    n_featdirs: float,
    featdirs: list[str],
    n_stats: float,
    stats: list[str],
    output_rootname: str,
    mask_file: InputPathType,
    atlas_flag: str | None = None,
    percent_convert_flag: bool = False,
    thresh_flag: bool = False,
    interp_thresh: float | None = 0.5,
    timeseries_flag: bool = False,
    weight_flag: bool = False,
    browser_flag: bool = False,
    coords: list[float] | None = None,
    runner: Runner | None = None,
) -> FeatqueryOutputs:
    """
    Tool to extract statistics and/or time series from FEAT directories.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FEAT
    
    Args:
        n_featdirs: Number of feat directories.
        featdirs: List of feat directories.
        n_stats: Number of stats to query.
        stats: List of stats.
        output_rootname: Root name for output files.
        mask_file: Mask file used as a reference for coordinates; if relative,\
            searched within each FEAT directory.
        atlas_flag: Use selected atlas to generate label (etc.) information.
        percent_convert_flag: Convert PE / COPE values into percentages.
        thresh_flag: Threshold stats images.
        interp_thresh: Affect size of resampled masks by changing\
            post-interpolation thresholding (default 0.5).
        timeseries_flag: Create time-series plots.
        weight_flag: Do not binarise mask (allow weighting).
        browser_flag: Popup results in browser when finished.
        coords: Coordinates specified in voxels (X Y Z).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FeatqueryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FEATQUERY_METADATA)
    cargs = []
    cargs.append("featquery")
    cargs.append(str(n_featdirs))
    cargs.extend(featdirs)
    cargs.append(str(n_stats))
    cargs.extend(stats)
    cargs.append(output_rootname)
    if atlas_flag is not None:
        cargs.extend([
            "-a",
            atlas_flag
        ])
    if percent_convert_flag:
        cargs.append("-p")
    if thresh_flag:
        cargs.append("-t")
    if interp_thresh is not None:
        cargs.extend([
            "-i",
            str(interp_thresh)
        ])
    if timeseries_flag:
        cargs.append("-s")
    if weight_flag:
        cargs.append("-w")
    if browser_flag:
        cargs.append("-b")
    cargs.append(execution.input_file(mask_file))
    if coords is not None:
        cargs.extend([
            "-vox",
            *map(str, coords)
        ])
    ret = FeatqueryOutputs(
        root=execution.output_file("."),
        query_report=execution.output_file(output_rootname + "_queryreport.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FEATQUERY_METADATA",
    "FeatqueryOutputs",
    "featquery",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SYSTEMNOISE_METADATA = Metadata(
    id="342f5f005f89ccb84419c01a8e3c010a5933be2a.boutiques",
    name="systemnoise",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SystemnoiseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `systemnoise(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_signal_file: OutputPathType
    """Output signal with added system noise"""


def systemnoise(
    runner: Runner | None = None,
) -> SystemnoiseOutputs:
    """
    Tool for adding system noise to a given signal using FSL's utilities.
    
    Author: University of Oxford (Mark Jenkinson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/SystemNoise
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SystemnoiseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SYSTEMNOISE_METADATA)
    cargs = []
    cargs.append("systemnoise")
    cargs.append("[OPTIONS]")
    ret = SystemnoiseOutputs(
        root=execution.output_file("."),
        output_signal_file=execution.output_file("[OUTPUT_SIGNAL]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SYSTEMNOISE_METADATA",
    "SystemnoiseOutputs",
    "systemnoise",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GLTSYMTEST_METADATA = Metadata(
    id="332931d9c4a4e4a6d9609bf286d3aa59c1c5917b.boutiques",
    name="GLTsymtest",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GltsymtestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gltsymtest(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def gltsymtest(
    varlist: str,
    expr: list[str],
    badonly: bool = False,
    runner: Runner | None = None,
) -> GltsymtestOutputs:
    """
    A tool to test the validity of '-gltsym' strings for use with 3dDeconvolve or
    3dREMLfit.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/GLTsymtest.html
    
    Args:
        varlist: A list of allowed variable names in the expression, separated\
            by commas, semicolons, and/or spaces.
        expr: GLT symbolic expression(s), enclosed in quotes.
        badonly: A flag to only output BAD messages rather than all messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GltsymtestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GLTSYMTEST_METADATA)
    cargs = []
    cargs.append("GLTsymtest")
    if badonly:
        cargs.append("-badonly")
    cargs.append(varlist)
    cargs.extend(expr)
    ret = GltsymtestOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GLTSYMTEST_METADATA",
    "GltsymtestOutputs",
    "gltsymtest",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GET_AFNI_PREFIX_METADATA = Metadata(
    id="319f4b6f23c4fb2f22807441a53e5648683d8b96.boutiques",
    name="@GetAfniPrefix",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGetAfniPrefixOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__get_afni_prefix(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__get_afni_prefix(
    name: InputPathType,
    suffix: str | None = None,
    runner: Runner | None = None,
) -> VGetAfniPrefixOutputs:
    """
    A tool to extract AFNI prefix from a given file path.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@GetAfniPrefix.html
    
    Args:
        name: Input file path for which the AFNI prefix will be extracted.
        suffix: Suffix string to append to the returned prefix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGetAfniPrefixOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GET_AFNI_PREFIX_METADATA)
    cargs = []
    cargs.append("@GetAfniPrefix")
    cargs.append(execution.input_file(name))
    if suffix is not None:
        cargs.append(suffix)
    ret = VGetAfniPrefixOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGetAfniPrefixOutputs",
    "V__GET_AFNI_PREFIX_METADATA",
    "v__get_afni_prefix",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIND_VARIANCE_LINES_TCSH_METADATA = Metadata(
    id="d945d03baa65a3eb582f1efc1233dd5c40de2056.boutiques",
    name="find_variance_lines.tcsh",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FindVarianceLinesTcshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `find_variance_lines_tcsh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    variance_maps: OutputPathType
    """Variance maps per run"""
    scaled_variance_maps: OutputPathType
    """Scaled variance maps per run"""
    cluster_reports: OutputPathType
    """Cluster reports"""
    jpeg_images: OutputPathType
    """JPEG images showing locations of high variance"""


def find_variance_lines_tcsh(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> FindVarianceLinesTcshOutputs:
    """
    Look for bars of high variance that might suggest scanner interference in EPI
    datasets.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/find_variance_lines.tcsh.html
    
    Args:
        input_files: Input EPI datasets.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FindVarianceLinesTcshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIND_VARIANCE_LINES_TCSH_METADATA)
    cargs = []
    cargs.append("find_variance_lines.tcsh")
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.append("[OPTIONS]")
    ret = FindVarianceLinesTcshOutputs(
        root=execution.output_file("."),
        variance_maps=execution.output_file("[OUTPUT_DIR]/variance_map_run*.nii.gz"),
        scaled_variance_maps=execution.output_file("[OUTPUT_DIR]/scaled_variance_map_run*.nii.gz"),
        cluster_reports=execution.output_file("[OUTPUT_DIR]/cluster_report_run*.txt"),
        jpeg_images=execution.output_file("[OUTPUT_DIR]/*.jpg"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIND_VARIANCE_LINES_TCSH_METADATA",
    "FindVarianceLinesTcshOutputs",
    "find_variance_lines_tcsh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EDDY_QUAD_METADATA = Metadata(
    id="55c16aa046b6af53dd6839c56b18fd79a0c73855.boutiques",
    name="eddy_quad",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class EddyQuadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `eddy_quad(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dir_qc: OutputPathType
    """Quality control data outputs"""


def eddy_quad(
    eddy_base: str,
    eddy_index: InputPathType,
    eddy_params: InputPathType,
    mask: InputPathType,
    bvals: InputPathType,
    runner: Runner | None = None,
) -> EddyQuadOutputs:
    """
    QUality Assessment for DMRI.
    
    Author: FMRIB Software Library
    
    Args:
        eddy_base: Basename (including path) specified when running EDDY.
        eddy_index: File containing indices for all volumes into acquisition\
            parameters.
        eddy_params: File containing acquisition parameters.
        mask: Binary mask file.
        bvals: b-values file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EddyQuadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EDDY_QUAD_METADATA)
    cargs = []
    cargs.append("eddy_quad")
    cargs.append(eddy_base)
    cargs.append("--eddyIdx")
    cargs.extend([
        "--eddyIdx",
        execution.input_file(eddy_index)
    ])
    cargs.append("--eddyParams")
    cargs.extend([
        "--eddyParams",
        execution.input_file(eddy_params)
    ])
    cargs.append("--mask")
    cargs.extend([
        "--mask",
        execution.input_file(mask)
    ])
    cargs.append("--bvals")
    cargs.extend([
        "--bvals",
        execution.input_file(bvals)
    ])
    cargs.append("[OPTIONS]")
    ret = EddyQuadOutputs(
        root=execution.output_file("."),
        output_dir_qc=execution.output_file("<output-dir>"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EDDY_QUAD_METADATA",
    "EddyQuadOutputs",
    "eddy_quad",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIXELFILTER_METADATA = Metadata(
    id="c8d0aa7a0b4f28c8cd4f545d783f49ce5f8b2c57.boutiques",
    name="fixelfilter",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class FixelfilterConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class FixelfilterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fixelfilter(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fixelfilter(
    matrix: InputPathType,
    input_: str,
    filter_: str,
    output: str,
    threshold_value: float | None = None,
    threshold_connectivity: float | None = None,
    fwhm: float | None = None,
    minweight: float | None = None,
    mask: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[FixelfilterConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> FixelfilterOutputs:
    """
    Perform filtering operations on fixel-based data.
    
    If the first input to the command is a specific fixel data file, then a
    filtered version of only that file will be generated by the command.
    Alternatively, if the input is the location of a fixel directory, then the
    command will create a duplicate of the fixel directory, and apply the
    specified filter operation to all fixel data files within the directory.
    
    References:
    
    .
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/fixelfilter.html
    
    Args:
        matrix: provide a fixel-fixel connectivity matrix for filtering\
            operations that require it.
        input_: the input: either a fixel data file, or a fixel directory (see\
            Description).
        filter_: the filtering operation to perform; options are: connect,\
            smooth.
        output: the output: either a fixel data file, or a fixel directory (see\
            Description).
        threshold_value: specify a threshold for the input fixel data file\
            values (default = 0.5).
        threshold_connectivity: specify a fixel-fixel connectivity threshold\
            for connected-component analysis (default = 0.10000000000000001).
        fwhm: the full-width half-maximum (FWHM) of the spatial component of\
            the smoothing filter (default = 10mm).
        minweight: apply a minimum threshold to smoothing weights (default =\
            0.01).
        mask: only perform smoothing within a specified binary fixel mask.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixelfilterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIXELFILTER_METADATA)
    cargs = []
    cargs.append("fixelfilter")
    cargs.extend([
        "-matrix",
        execution.input_file(matrix)
    ])
    if threshold_value is not None:
        cargs.extend([
            "-threshold_value",
            str(threshold_value)
        ])
    if threshold_connectivity is not None:
        cargs.extend([
            "-threshold_connectivity",
            str(threshold_connectivity)
        ])
    if fwhm is not None:
        cargs.extend([
            "-fwhm",
            str(fwhm)
        ])
    if minweight is not None:
        cargs.extend([
            "-minweight",
            str(minweight)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(input_)
    cargs.append(filter_)
    cargs.append(output)
    ret = FixelfilterOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIXELFILTER_METADATA",
    "FixelfilterConfig",
    "FixelfilterOutputs",
    "fixelfilter",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__CENTER_DISTANCE_METADATA = Metadata(
    id="b83f2a2ca9fa497ea99ff4923cf2b21f95c3dee6.boutiques",
    name="@Center_Distance",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VCenterDistanceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__center_distance(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    distance_output: OutputPathType
    """The calculated distance between the centers of DSET_1 and DSET_2"""


def v__center_distance(
    dset1: InputPathType,
    dset2: InputPathType,
    runner: Runner | None = None,
) -> VCenterDistanceOutputs:
    """
    Tool to calculate the distance between the centers of two datasets.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Center_Distance.html
    
    Args:
        dset1: First dataset file (e.g. file1.nii.gz).
        dset2: Second dataset file (e.g. file2.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VCenterDistanceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__CENTER_DISTANCE_METADATA)
    cargs = []
    cargs.append("@Center_Distance")
    cargs.append("-dset")
    cargs.append(execution.input_file(dset1))
    cargs.append(execution.input_file(dset2))
    ret = VCenterDistanceOutputs(
        root=execution.output_file("."),
        distance_output=execution.output_file("distance.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VCenterDistanceOutputs",
    "V__CENTER_DISTANCE_METADATA",
    "v__center_distance",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_LABEL_ADJACENCY_METADATA = Metadata(
    id="73b8f697c09de73b22005706eab881ce18e7cad1.boutiques",
    name="cifti-label-adjacency",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiLabelAdjacencyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_label_adjacency(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    adjacency_out: OutputPathType
    """the output cifti pconn adjacency matrix"""


def cifti_label_adjacency(
    label_in: InputPathType,
    adjacency_out: str,
    opt_left_surface_surface: InputPathType | None = None,
    opt_right_surface_surface: InputPathType | None = None,
    opt_cerebellum_surface_surface: InputPathType | None = None,
    runner: Runner | None = None,
) -> CiftiLabelAdjacencyOutputs:
    """
    Make adjacency matrix of a cifti label file.
    
    Find face-adjacent voxels and connected vertices that have different label
    values, and count them for each pair. Put the resulting counts into a
    parcellated connectivity file, with the diagonal being zero. This gives a
    rough estimate of how long or expansive the border between two labels is.
    
    Author: Washington University School of Medicin
    
    Args:
        label_in: the input cifti label file.
        adjacency_out: the output cifti pconn adjacency matrix.
        opt_left_surface_surface: specify the left surface to use: the left\
            surface file.
        opt_right_surface_surface: specify the right surface to use: the right\
            surface file.
        opt_cerebellum_surface_surface: specify the cerebellum surface to use:\
            the cerebellum surface file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelAdjacencyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_ADJACENCY_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-adjacency")
    cargs.append(execution.input_file(label_in))
    cargs.append(adjacency_out)
    if opt_left_surface_surface is not None:
        cargs.extend([
            "-left-surface",
            execution.input_file(opt_left_surface_surface)
        ])
    if opt_right_surface_surface is not None:
        cargs.extend([
            "-right-surface",
            execution.input_file(opt_right_surface_surface)
        ])
    if opt_cerebellum_surface_surface is not None:
        cargs.extend([
            "-cerebellum-surface",
            execution.input_file(opt_cerebellum_surface_surface)
        ])
    ret = CiftiLabelAdjacencyOutputs(
        root=execution.output_file("."),
        adjacency_out=execution.output_file(adjacency_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_LABEL_ADJACENCY_METADATA",
    "CiftiLabelAdjacencyOutputs",
    "cifti_label_adjacency",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DFFT_METADATA = Metadata(
    id="f63c1682b30f92c01d9b402bed2cf0a390165697.boutiques",
    name="1dfft",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dfftOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dfft(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_fft: OutputPathType
    """Output file with the absolute value of the FFT of the input columns."""


def v_1dfft(
    infile: InputPathType,
    outfile: str,
    runner: Runner | None = None,
) -> V1dfftOutputs:
    """
    Compute the absolute value of the FFT of input columns from an AFNI 1D file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dfft.html
    
    Args:
        infile: Input .1D file containing an ASCII list of numbers arranged in\
            columns.
        outfile: Output file to store the FFT results.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dfftOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DFFT_METADATA)
    cargs = []
    cargs.append("1dfft")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(infile))
    cargs.append(outfile)
    ret = V1dfftOutputs(
        root=execution.output_file("."),
        out_fft=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dfftOutputs",
    "V_1DFFT_METADATA",
    "v_1dfft",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FEAT_MODEL_METADATA = Metadata(
    id="fc17fd0e3d064d3ee3d8b2f284af9132f7aaef7e.boutiques",
    name="feat_model",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FeatModelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `feat_model(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def feat_model(
    design_name_root: str,
    confound_matrix: InputPathType | None = None,
    runner: Runner | None = None,
) -> FeatModelOutputs:
    """
    Generate design matrices for use by FEAT.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FEAT
    
    Args:
        design_name_root: Design name root.
        confound_matrix: Confound matrix text file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FeatModelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FEAT_MODEL_METADATA)
    cargs = []
    cargs.append("feat_model")
    cargs.append(design_name_root)
    if confound_matrix is not None:
        cargs.append(execution.input_file(confound_matrix))
    ret = FeatModelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FEAT_MODEL_METADATA",
    "FeatModelOutputs",
    "feat_model",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

COUNT_METADATA = Metadata(
    id="3836250f08dfeed6fcad0e888310644533ee13db.boutiques",
    name="count",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class CountOutputs(typing.NamedTuple):
    """
    Output object returned when calling `count(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def count(
    bot: str,
    top: str,
    step: str | None = None,
    runner: Runner | None = None,
) -> CountOutputs:
    """
    Numbered copies generator with custom format support and random sequence
    options.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/count.html
    
    Args:
        bot: Starting number or character.
        top: Ending number or character.
        step: Stride step or mode (integer step size, R#, S# or S).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CountOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(COUNT_METADATA)
    cargs = []
    cargs.append("count")
    cargs.append("[OPTIONS]")
    cargs.append(bot)
    cargs.append(top)
    if step is not None:
        cargs.append(step)
    ret = CountOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "COUNT_METADATA",
    "CountOutputs",
    "count",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

OVERLAY_METADATA = Metadata(
    id="1b2de06d3c3c55476b10678cfb33eedfc35927e0.boutiques",
    name="overlay",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class OverlayOutputs(typing.NamedTuple):
    """
    Output object returned when calling `overlay(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file_outfile: OutputPathType | None
    """Combined image volume."""


def overlay(
    background_image: InputPathType,
    stat_image: InputPathType,
    stat_thresh: list[float],
    out_type: typing.Literal["float", "int"] | None = "float",
    use_checkerboard: bool = False,
    full_bg_range: bool = False,
    stat_image2: InputPathType | None = None,
    stat_thresh2: list[float] | None = None,
    out_file: InputPathType | None = None,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    runner: Runner | None = None,
) -> OverlayOutputs:
    """
    Use FSL's overlay command to combine background and statistical images into one
    volume.
    
    Author: Nipype (interface)
    
    Args:
        background_image: Image to use as background.
        stat_image: Statistical image to overlay in color.
        stat_thresh: (a float, a float). Min and max values for the statistical\
            overlay.
        out_type: 'float' or 'int'. Write output with float or int.
        use_checkerboard: Use checkerboard mask for overlay.
        full_bg_range: Use full range of background image.
        stat_image2: Second statistical image to overlay in color.
        stat_thresh2: (a float, a float). Min and max values for second\
            statistical overlay.
        out_file: Combined image volume.
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `OverlayOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(OVERLAY_METADATA)
    cargs = []
    cargs.append("Overlay")
    cargs.append("[TRANSPARENCY]")
    if out_type is not None:
        cargs.append(out_type)
    if use_checkerboard:
        cargs.append("-c")
    cargs.append(execution.input_file(background_image))
    if full_bg_range:
        cargs.append("-A")
    cargs.append(execution.input_file(stat_image))
    cargs.extend(map(str, stat_thresh))
    cargs.append("[SHOW_NEGATIVE_STATS]")
    if stat_image2 is not None:
        cargs.append(execution.input_file(stat_image2))
    if stat_thresh2 is not None:
        cargs.extend(map(str, stat_thresh2))
    if out_file is not None:
        cargs.append(execution.input_file(out_file))
    if output_type is not None:
        cargs.append(output_type)
    ret = OverlayOutputs(
        root=execution.output_file("."),
        out_file_outfile=execution.output_file(pathlib.Path(out_file).name) if (out_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "OVERLAY_METADATA",
    "OverlayOutputs",
    "overlay",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLCHFILETYPE_METADATA = Metadata(
    id="1d31f3c460cabb5d7f9442a7a8923cfcb593ed4f.boutiques",
    name="fslchfiletype",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslchfiletypeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslchfiletype(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType | None
    """Output file with the new file type."""


def fslchfiletype(
    filetype: str,
    filename: InputPathType,
    filename2: str | None = None,
    runner: Runner | None = None,
) -> FslchfiletypeOutputs:
    """
    Tool to change the file type of an image file or copy it to a new file.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils#FSL_UTILITIES
    
    Args:
        filetype: The type of the file to convert to. Valid values include:\
            ANALYZE, ANALYZE_GZ, NIFTI, NIFTI_GZ, NIFTI_PAIR, NIFTI_PAIR_GZ,\
            NIFTI2, NIFTI2_GZ, NIFTI2_PAIR, NIFTI2_PAIR_GZ.
        filename: The name of the input image file.
        filename2: The name of the output image file (optional).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslchfiletypeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLCHFILETYPE_METADATA)
    cargs = []
    cargs.append("fslchfiletype")
    cargs.append(filetype)
    cargs.append(execution.input_file(filename))
    if filename2 is not None:
        cargs.append(filename2)
    ret = FslchfiletypeOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(filename2) if (filename2 is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLCHFILETYPE_METADATA",
    "FslchfiletypeOutputs",
    "fslchfiletype",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FATCAT_MATPLOT_METADATA = Metadata(
    id="6c76a16c1c64f9d17e99b60413144fd110dedb16.boutiques",
    name="FATCAT_matplot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatcatMatplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fatcat_matplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fatcat_matplot(
    directory: str,
    shiny_folder: bool = False,
    runner: Runner | None = None,
) -> FatcatMatplotOutputs:
    """
    Launch a shiny app to visualize .netcc and/or .grid files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/FATCAT_matplot.html
    
    Args:
        directory: Path to a folder containing .netcc and/or .grid files.
        shiny_folder: Use a custom shiny folder (for testing purposes).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatcatMatplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FATCAT_MATPLOT_METADATA)
    cargs = []
    cargs.append("FATCAT_matplot")
    cargs.append(directory)
    if shiny_folder:
        cargs.append("-ShinyFolder")
    ret = FatcatMatplotOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FATCAT_MATPLOT_METADATA",
    "FatcatMatplotOutputs",
    "fatcat_matplot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DSVD_METADATA = Metadata(
    id="1e845a4ea67d4f4390b3cc2a7cdf74c42dcccaf5.boutiques",
    name="1dsvd",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dsvdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dsvd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout: OutputPathType
    """Output of the SVD computation"""


def v_1dsvd(
    input_files: list[InputPathType],
    one: bool = False,
    vmean: bool = False,
    vnorm: bool = False,
    cond: bool = False,
    sing: bool = False,
    sort: bool = False,
    nosort: bool = False,
    asort: bool = False,
    left_eigenvectors: bool = False,
    num_eigenvectors: str | None = None,
    runner: Runner | None = None,
) -> V1dsvdOutputs:
    """
    Computes SVD of the matrix formed by the 1D file(s) and outputs the result on
    stdout.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dsvd.html
    
    Args:
        input_files: Input 1D file(s) for SVD computation.
        one: Make 1st vector be all 1's.
        vmean: Remove mean from each vector (cannot be used with -one).
        vnorm: Make L2-norm of each vector = 1 before SVD.
        cond: Only print condition number (ratio of extremes).
        sing: Only print singular values.
        sort: Sort singular values in descending order (default).
        nosort: Don't sort singular values.
        asort: Sort singular values in ascending order.
        left_eigenvectors: Only output left eigenvectors in .1D format.
        num_eigenvectors: Specify number of left eigenvectors to output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dsvdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DSVD_METADATA)
    cargs = []
    cargs.append("1dsvd")
    if one:
        cargs.append("-one")
    if vmean:
        cargs.append("-vmean")
    if vnorm:
        cargs.append("-vnorm")
    if cond:
        cargs.append("-cond")
    if sing:
        cargs.append("-sing")
    if sort:
        cargs.append("-sort")
    if nosort:
        cargs.append("-nosort")
    if asort:
        cargs.append("-asort")
    if left_eigenvectors:
        cargs.append("-1Dleft")
    if num_eigenvectors is not None:
        cargs.extend([
            "-nev",
            num_eigenvectors
        ])
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V1dsvdOutputs(
        root=execution.output_file("."),
        stdout=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dsvdOutputs",
    "V_1DSVD_METADATA",
    "v_1dsvd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SCRIPT_CHECK_METADATA = Metadata(
    id="5545e4317d4b1d759b3e8c38e387264935f82b0f.boutiques",
    name="@ScriptCheck",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VScriptCheckOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__script_check(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    uncleaned_file: OutputPathType
    """Uncleaned original file with specified suffix"""
    cleaned_file: OutputPathType
    """Cleaned file if -clean option is used"""


def v__script_check(
    scripts: list[InputPathType],
    clean: bool = False,
    suffix: str | None = None,
    runner: Runner | None = None,
) -> VScriptCheckOutputs:
    """
    Checks scripts for improperly terminated lines and optionally cleans them.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@ScriptCheck.html
    
    Args:
        scripts: Scripts to be checked for improperly terminated lines.
        clean: Clean bad line breaks.
        suffix: Rename uncleaned file with specified suffix. Default is .uncln.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VScriptCheckOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SCRIPT_CHECK_METADATA)
    cargs = []
    cargs.append("@ScriptCheck")
    if clean:
        cargs.append("-clean")
    cargs.append("[SUFFIX_FLAG]")
    if suffix is not None:
        cargs.extend([
            "-suffix",
            suffix
        ])
    cargs.extend([execution.input_file(f) for f in scripts])
    ret = VScriptCheckOutputs(
        root=execution.output_file("."),
        uncleaned_file=execution.output_file("{SCRIPT}.uncln"),
        cleaned_file=execution.output_file("{SCRIPT}"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VScriptCheckOutputs",
    "V__SCRIPT_CHECK_METADATA",
    "v__script_check",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_D99_MACAQUE_METADATA = Metadata(
    id="11b48efb49cea8ca46bf421bd6a126147413494b.boutiques",
    name="@Install_D99_macaque",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallD99MacaqueOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_d99_macaque(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    readme_file: OutputPathType
    """Readme file with details about the installed atlas."""
    atlas_files: OutputPathType
    """Installed D99 macaque version 2 atlas files."""


def v__install_d99_macaque(
    wget_download: bool = False,
    curl_download: bool = False,
    runner: Runner | None = None,
) -> VInstallD99MacaqueOutputs:
    """
    Installs the D99 macaque version 2 atlases for subcortical regions in the
    macaque monkey.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_D99_macaque.html
    
    Args:
        wget_download: Use wget to download archive. Script chooses by default\
            with preference for curl.
        curl_download: Use curl to download archive. Script chooses by default\
            with preference for curl.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallD99MacaqueOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_D99_MACAQUE_METADATA)
    cargs = []
    cargs.append("@Install_D99_macaque")
    if wget_download:
        cargs.append("-wget")
    if curl_download:
        cargs.append("-curl")
    ret = VInstallD99MacaqueOutputs(
        root=execution.output_file("."),
        readme_file=execution.output_file("README.txt"),
        atlas_files=execution.output_file("D99_macaque_v2/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallD99MacaqueOutputs",
    "V__INSTALL_D99_MACAQUE_METADATA",
    "v__install_d99_macaque",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_NORMALITY_TEST_METADATA = Metadata(
    id="0c4fc6300ae871742266f64fa61a03d97788ba70.boutiques",
    name="3dNormalityTest",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dNormalityTestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_normality_test(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output dataset with results"""


def v_3d_normality_test(
    input_: InputPathType,
    prefix: str,
    noexp: bool = False,
    pval: bool = False,
    runner: Runner | None = None,
) -> V3dNormalityTestOutputs:
    """
    This program tests the input values at each voxel for normality using the
    Anderson-Darling method.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dNormalityTest.html
    
    Args:
        input_: Specifies the input dataset.
        prefix: Specifies the name for the output dataset.
        noexp: Do not convert the A-D statistic to an exponentially distributed\
            value.
        pval: Output the results as a pure (estimated) p-value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dNormalityTestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_NORMALITY_TEST_METADATA)
    cargs = []
    cargs.append("3dNormalityTest")
    cargs.append(execution.input_file(input_))
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    if noexp:
        cargs.append("-noexp")
    if pval:
        cargs.append("-pval")
    ret = V3dNormalityTestOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + "+orig.*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dNormalityTestOutputs",
    "V_3D_NORMALITY_TEST_METADATA",
    "v_3d_normality_test",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_STIM_TIMES_PY_METADATA = Metadata(
    id="10a9a0b8255c3a6827c96f89181ab95d17e57c15.boutiques",
    name="make_stim_times.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MakeStimTimesPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_stim_times_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_stim_times_01: OutputPathType
    """Output stim_times file for first stimulus class"""
    out_stim_times_02: OutputPathType
    """Output stim_times file for second stimulus class"""
    out_stim_times_03: OutputPathType
    """Output stim_times file for third stimulus class"""


def make_stim_times_py(
    files: list[InputPathType],
    prefix: str,
    tr: float,
    nruns: float,
    nt_: float,
    run_trs: list[float] | None = None,
    offset: float | None = None,
    labels: list[str] | None = None,
    no_consec_events: bool = False,
    amplitudes: bool = False,
    show_valid_opts: bool = False,
    verbose: float | None = None,
    runner: Runner | None = None,
) -> MakeStimTimesPyOutputs:
    """
    Convert a set of 0/1 stim files into a set of stim_times files, or convert
    real-valued files into those for use with -stim_times_AM2.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/make_stim_times.py.html
    
    Args:
        files: Specify stim files.
        prefix: Output prefix for files.
        tr: TR time, in seconds.
        nruns: Number of runs.
        nt_: Number of TRs per run.
        run_trs: Specify TRs per run, if they differ.
        offset: Add OFFSET to all output times.
        labels: Provide labels for filenames.
        no_consec_events: Do not allow consecutive events.
        amplitudes: Marry times with amplitudes.
        show_valid_opts: Output all options.
        verbose: Provide verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeStimTimesPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_STIM_TIMES_PY_METADATA)
    cargs = []
    cargs.append("make_stim_times.py")
    cargs.extend([execution.input_file(f) for f in files])
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-tr",
        str(tr)
    ])
    cargs.extend([
        "-nruns",
        str(nruns)
    ])
    cargs.extend([
        "-nt",
        str(nt_)
    ])
    if run_trs is not None:
        cargs.extend(map(str, run_trs))
    if offset is not None:
        cargs.extend([
            "-offset",
            str(offset)
        ])
    if labels is not None:
        cargs.extend([
            "-labels",
            *labels
        ])
    if no_consec_events:
        cargs.append("-no_consec")
    if amplitudes:
        cargs.append("-amplitudes")
    if show_valid_opts:
        cargs.append("-show_valid_opts")
    if verbose is not None:
        cargs.extend([
            "-verb",
            str(verbose)
        ])
    ret = MakeStimTimesPyOutputs(
        root=execution.output_file("."),
        out_stim_times_01=execution.output_file(prefix + ".01.1D"),
        out_stim_times_02=execution.output_file(prefix + ".02.1D"),
        out_stim_times_03=execution.output_file(prefix + ".03.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_STIM_TIMES_PY_METADATA",
    "MakeStimTimesPyOutputs",
    "make_stim_times_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_DW_GRAD_O_MAT___METADATA = Metadata(
    id="1b134b48311299bc6a0c83db7d4184e0a750ef98.boutiques",
    name="1dDW_Grad_o_Mat++",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dDwGradOMatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_dw_grad_o_mat__(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file of gradients or matrices"""
    out_row_bval_file: OutputPathType
    """Output b-values file in a single row"""
    out_col_bval_file: OutputPathType
    """Output b-values file in a single column"""


def v_1d_dw_grad_o_mat__(
    no_flip: bool = False,
    runner: Runner | None = None,
) -> V1dDwGradOMatOutputs:
    """
    Manipulation of diffusion-weighted (DW) gradient vector files, b-value files,
    and b- or g-matrices with various input and output configurations.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dDW_Grad_o_Mat++.html
    
    Args:
        no_flip: Don't change any gradient/matrix signs (default behavior).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dDwGradOMatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_DW_GRAD_O_MAT___METADATA)
    cargs = []
    cargs.append("1dDW_Grad_o_Mat++")
    cargs.append("[INPUT_OPTION]")
    cargs.append("INFILE")
    if no_flip:
        cargs.append("-no_flip")
    cargs.append("[OUTPUT_OPTION]")
    cargs.append("OUTFILE")
    cargs.append("[ADDITIONAL_OPTIONS]")
    ret = V1dDwGradOMatOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("[OUTFILE]"),
        out_row_bval_file=execution.output_file("[BB]"),
        out_col_bval_file=execution.output_file("[BB]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dDwGradOMatOutputs",
    "V_1D_DW_GRAD_O_MAT___METADATA",
    "v_1d_dw_grad_o_mat__",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ESTIMATE_FIBER_BINGHAMS_METADATA = Metadata(
    id="4f5460773358994ad9446baaa6f31bc1cd5c7f51.boutiques",
    name="estimate-fiber-binghams",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class EstimateFiberBinghamsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `estimate_fiber_binghams(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti fiber distributons file"""


def estimate_fiber_binghams(
    merged_f1samples: InputPathType,
    merged_th1samples: InputPathType,
    merged_ph1samples: InputPathType,
    merged_f2samples: InputPathType,
    merged_th2samples: InputPathType,
    merged_ph2samples: InputPathType,
    merged_f3samples: InputPathType,
    merged_th3samples: InputPathType,
    merged_ph3samples: InputPathType,
    label_volume: InputPathType,
    cifti_out: str,
    runner: Runner | None = None,
) -> EstimateFiberBinghamsOutputs:
    """
    Estimate fiber orientation distributions from bedpostx samples.
    
    This command does an estimation of a bingham distribution for each fiber
    orientation in each voxel which is labeled a structure identifier. These
    labelings come from the <label-volume> argument, which must have labels that
    match the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Washington University School of Medicin
    
    Args:
        merged_f1samples: fiber 1 strength samples.
        merged_th1samples: fiber 1 theta samples.
        merged_ph1samples: fiber 1 phi samples.
        merged_f2samples: fiber 2 strength samples.
        merged_th2samples: fiber 2 theta samples.
        merged_ph2samples: fiber 2 phi samples.
        merged_f3samples: fiber 3 strength samples.
        merged_th3samples: fiber 3 theta samples.
        merged_ph3samples: fiber 3 phi samples.
        label_volume: volume of cifti structure labels.
        cifti_out: output cifti fiber distributons file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EstimateFiberBinghamsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ESTIMATE_FIBER_BINGHAMS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-estimate-fiber-binghams")
    cargs.append(execution.input_file(merged_f1samples))
    cargs.append(execution.input_file(merged_th1samples))
    cargs.append(execution.input_file(merged_ph1samples))
    cargs.append(execution.input_file(merged_f2samples))
    cargs.append(execution.input_file(merged_th2samples))
    cargs.append(execution.input_file(merged_ph2samples))
    cargs.append(execution.input_file(merged_f3samples))
    cargs.append(execution.input_file(merged_th3samples))
    cargs.append(execution.input_file(merged_ph3samples))
    cargs.append(execution.input_file(label_volume))
    cargs.append(cifti_out)
    ret = EstimateFiberBinghamsOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ESTIMATE_FIBER_BINGHAMS_METADATA",
    "EstimateFiberBinghamsOutputs",
    "estimate_fiber_binghams",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL2ASCII_METADATA = Metadata(
    id="4148252e7c8dae4324e50749f3366f693fc6020c.boutiques",
    name="fsl2ascii",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Fsl2asciiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl2ascii(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_ascii_file: OutputPathType
    """Output ASCII text file"""


def fsl2ascii(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> Fsl2asciiOutputs:
    """
    Convert NIfTI image or analyze 7.5 format file to ASCII text file.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        input_file: Input NIfTI (or analyze 7.5 format) image.
        output_file: Output ASCII text file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fsl2asciiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL2ASCII_METADATA)
    cargs = []
    cargs.append("fsl2ascii")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = Fsl2asciiOutputs(
        root=execution.output_file("."),
        output_ascii_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL2ASCII_METADATA",
    "Fsl2asciiOutputs",
    "fsl2ascii",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EDDY_COMBINE_METADATA = Metadata(
    id="db7603668c046fb6fd5779660a9255000bc5c8af.boutiques",
    name="eddy_combine",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class EddyCombineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `eddy_combine(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    combined_data: OutputPathType
    """Combined positive and negative phase-encoded data"""
    combined_bvals: OutputPathType
    """Combined b-values file"""
    combined_bvecs: OutputPathType
    """Combined b-vectors file"""


def eddy_combine(
    pos_data: InputPathType,
    pos_bvals: InputPathType,
    pos_bvecs: InputPathType,
    pos_series_vol: float,
    neg_data: InputPathType,
    neg_bvals: InputPathType,
    neg_bvecs: InputPathType,
    neg_series_vol: float,
    output_path: str,
    only_matched_flag: int,
    runner: Runner | None = None,
) -> EddyCombineOutputs:
    """
    Combines diffusion data sets with opposite phase encoding directions for use
    with FSL's EDDY.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        pos_data: Path to the positive phase-encoded data file (e.g.\
            PosData.nii.gz).
        pos_bvals: Path to the positive phase-encoded b-values file (e.g.\
            Posbvals).
        pos_bvecs: Path to the positive phase-encoded b-vectors file (e.g.\
            Posbvecs).
        pos_series_vol: Positive series volume count.
        neg_data: Path to the negative phase-encoded data file (e.g.\
            NegData.nii.gz).
        neg_bvals: Path to the negative phase-encoded b-values file (e.g.\
            Negbvals).
        neg_bvecs: Path to the negative phase-encoded b-vectors file (e.g.\
            Negbvecs).
        neg_series_vol: Negative series volume count.
        output_path: Output directory path.
        only_matched_flag: Flag to include only matched volumes (set to 1 to\
            include only matched volumes, otherwise 0).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EddyCombineOutputs`).
    """
    if not (0 <= only_matched_flag <= 1): 
        raise ValueError(f"'only_matched_flag' must be between 0 <= x <= 1 but was {only_matched_flag}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(EDDY_COMBINE_METADATA)
    cargs = []
    cargs.append("eddy_combine")
    cargs.append(execution.input_file(pos_data))
    cargs.append(execution.input_file(pos_bvals))
    cargs.append(execution.input_file(pos_bvecs))
    cargs.append(str(pos_series_vol))
    cargs.append(execution.input_file(neg_data))
    cargs.append(execution.input_file(neg_bvals))
    cargs.append(execution.input_file(neg_bvecs))
    cargs.append(str(neg_series_vol))
    cargs.append(output_path)
    cargs.append(str(only_matched_flag))
    ret = EddyCombineOutputs(
        root=execution.output_file("."),
        combined_data=execution.output_file(output_path + "/combined_data.nii.gz"),
        combined_bvals=execution.output_file(output_path + "/combined_bvals"),
        combined_bvecs=execution.output_file(output_path + "/combined_bvecs"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EDDY_COMBINE_METADATA",
    "EddyCombineOutputs",
    "eddy_combine",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DESIGN_TTEST2_METADATA = Metadata(
    id="1aac8635c8fa937d56e12e982bc15b5f166c599f.boutiques",
    name="design_ttest2",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class DesignTtest2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `design_ttest2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def design_ttest2(
    design_files_rootname: str,
    ngroupa: float,
    ngroupb: float,
    include_mean_contrasts: bool = False,
    runner: Runner | None = None,
) -> DesignTtest2Outputs:
    """
    Command for generating group mean contrasts for a two-sample t-test design.
    
    Author: Analysis Group, FMRIB, Oxford, UK
    
    Args:
        design_files_rootname: Root name for design files.
        ngroupa: Number of subjects in group A.
        ngroupb: Number of subjects in group B.
        include_mean_contrasts: Include individual group mean contrasts.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DesignTtest2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DESIGN_TTEST2_METADATA)
    cargs = []
    cargs.append("design_ttest2")
    cargs.append(design_files_rootname)
    cargs.append(str(ngroupa))
    cargs.append(str(ngroupb))
    if include_mean_contrasts:
        cargs.append("-m")
    ret = DesignTtest2Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DESIGN_TTEST2_METADATA",
    "DesignTtest2Outputs",
    "design_ttest2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ATROPOS_METADATA = Metadata(
    id="89ba3be34b24cc2c34a5c94b22919ec83f82ec3c.boutiques",
    name="atropos",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AtroposOutputs(typing.NamedTuple):
    """
    Output object returned when calling `atropos(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    classified_image: OutputPathType
    """The classified image output file."""
    posterior_probability_images: OutputPathType
    """Optional posterior probability images output files."""


def atropos(
    intensity_image: list[str],
    initialization: str,
    mask_image: str,
    likelihood_model: str,
    output: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    bspline: str | None = "6,1x1x...,3",
    partial_volume_label_set: list[str] | None = None,
    use_partial_volume_likelihoods: typing.Literal[0, 1] | None = None,
    posterior_formulation: str | None = None,
    convergence: str = "[5,0.001]",
    mrf: str | None = "0.3,1x1x...",
    icm: str | None = "1,1,''",
    use_random_seed: typing.Literal[0, 1] | None = None,
    minimize_memory_usage: typing.Literal[0, 1] | None = None,
    winsorize_outliers: str | None = None,
    use_euclidean_distance: typing.Literal[0, 1] | None = None,
    label_propagation: str | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> AtroposOutputs:
    """
    A finite mixture modeling (FMM) segmentation approach with possibilities for
    specifying prior constraints. These prior constraints include the specification
    of a prior label image, prior probability images (one for each class), and/or an
    MRF prior to enforce spatial smoothing of the labels. All segmentation images
    including priors and masks must be in the same voxel and physical space. Similar
    algorithms include FAST and SPM.
    
    Author: Advanced Normalization Tools (ANTs) Contributors
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        intensity_image: One or more scalar images is specified for\
            segmentation. For segmentation scenarios with no prior information, the\
            first scalar image encountered on the command line is used to order\
            labelings such that the class with the smallest intensity signature is\
            class '1' through class 'N' which represents the voxels with the\
            largest intensity values. The optional adaptive smoothing weight\
            parameter is applicable only when using prior label or probability\
            images. This scalar parameter is to be specified between [0,1] which\
            smooths each labeled region separately and modulates the intensity\
            measurement at each voxel in each intensity image between the original\
            intensity and its smoothed counterpart. The smoothness parameters are\
            governed by the -b/--bspline option.
        initialization: To initialize the FMM parameters, one of the specified\
            options (Random, Otsu, KMeans, PriorProbabilityImages, or\
            PriorLabelImage) must be used.
        mask_image: The image mask (which is required) defines the region which\
            is to be labeled by the Atropos algorithm.
        likelihood_model: Both parametric and non-parametric options exist in\
            Atropos.
        output: The output consists of a labeled image where each voxel in the\
            masked region is assigned a label from 1, 2, ..., N. Optionally, one\
            can also output the posterior probability images specified in the same\
            format as the prior probability images, e.g. posterior%02d.nii.gz\
            (C-style file name formatting).
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, Atropos tries to infer\
            the dimensionality from the first input image.
        bspline: If the adaptive smoothing weights are > 0, the intensity\
            images are smoothed in calculating the likelihood values. This is to\
            account for subtle intensity differences across the same tissue\
            regions.
        partial_volume_label_set: The partial volume estimation option allows\
            one to model mixtures of classes within single voxels.
        use_partial_volume_likelihoods: The user can specify whether or not to\
            use the partial volume likelihoods.
        posterior_formulation: Different posterior probability formulations are\
            possible as are different update options.
        convergence: Convergence is determined by calculating the mean maximum\
            posterior probability over the region of interest at each iteration.\
            When this value decreases or increases less than the specified\
            threshold from the previous iteration or the maximum number of\
            iterations is exceeded the program terminates.
        mrf: Markov random field (MRF) theory provides a general framework for\
            enforcing spatially contextual constraints on the segmentation\
            solution.
        icm: Asynchronous updating requires the construction of an ICM code\
            image which is a label image (with labels in the range\
            {1,..,MaximumICMCode}) constructed such that no MRF neighborhood has\
            duplicate ICM code labels.
        use_random_seed: Initialize internal random number generator with a\
            random seed.
        minimize_memory_usage: By default, memory usage is not minimized,\
            however, if this is needed, the various probability and distance images\
            are calculated on the fly instead of being stored in memory at each\
            iteration. Also, if prior probability images are used, only the\
            non-negligible pixel values are stored in memory.
        winsorize_outliers: To remove the effects of outliers in calculating\
            the weighted mean and weighted covariance, the user can opt to remove\
            the outliers through the options specified below.
        use_euclidean_distance: Given prior label or probability images, the\
            labels are propagated throughout the masked region so that every voxel\
            in the mask is labeled.
        label_propagation: The propagation of each prior label can be\
            controlled by the lambda and boundary probability parameters.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AtroposOutputs`).
    """
    if partial_volume_label_set is not None and not (1 <= len(partial_volume_label_set)): 
        raise ValueError(f"Length of 'partial_volume_label_set' must be greater than 1 but was {len(partial_volume_label_set)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(ATROPOS_METADATA)
    cargs = []
    cargs.append("Atropos")
    if image_dimensionality is not None:
        cargs.extend([
            "--image-dimensionality",
            str(image_dimensionality)
        ])
    cargs.extend([
        "--intensity-image",
        *intensity_image
    ])
    if bspline is not None:
        cargs.extend([
            "--bspline",
            bspline
        ])
    cargs.extend([
        "--initialization",
        initialization
    ])
    if partial_volume_label_set is not None:
        cargs.extend([
            "--partial-volume-label-set",
            *partial_volume_label_set
        ])
    if use_partial_volume_likelihoods is not None:
        cargs.extend([
            "--use-partial-volume-likelihoods",
            str(use_partial_volume_likelihoods)
        ])
    if posterior_formulation is not None:
        cargs.extend([
            "--posterior-formulation",
            posterior_formulation
        ])
    cargs.extend([
        "-x",
        mask_image
    ])
    cargs.extend([
        "--convergence",
        convergence
    ])
    cargs.extend([
        "--likelihood-model",
        likelihood_model
    ])
    if mrf is not None:
        cargs.extend([
            "-m",
            mrf
        ])
    if icm is not None:
        cargs.extend([
            "--icm",
            icm
        ])
    if use_random_seed is not None:
        cargs.extend([
            "--use-random-seed",
            str(use_random_seed)
        ])
    cargs.extend([
        "-o",
        output
    ])
    if minimize_memory_usage is not None:
        cargs.extend([
            "--minimize-memory-usage",
            str(minimize_memory_usage)
        ])
    if winsorize_outliers is not None:
        cargs.extend([
            "--winsorize-outliers",
            winsorize_outliers
        ])
    if use_euclidean_distance is not None:
        cargs.extend([
            "--use-euclidean-distance",
            str(use_euclidean_distance)
        ])
    if label_propagation is not None:
        cargs.extend([
            "--label-propagation",
            label_propagation
        ])
    if verbose is not None:
        cargs.extend([
            "--verbose",
            str(verbose)
        ])
    ret = AtroposOutputs(
        root=execution.output_file("."),
        classified_image=execution.output_file("[CLASSIFIED_IMAGE]"),
        posterior_probability_images=execution.output_file("[POSTERIOR_PROBABILITY_IMAGE_FILE_FORMAT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ATROPOS_METADATA",
    "AtroposOutputs",
    "atropos",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_CORRELATE_METADATA = Metadata(
    id="bc0a1b16f11fccd44b88079e012921935b8dc003.boutiques",
    name="1dCorrelate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dCorrelateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_correlate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1d_correlate(
    input_files: list[InputPathType],
    ktaub: bool = False,
    nboot: float | None = None,
    alpha: float | None = None,
    blk: bool = False,
    runner: Runner | None = None,
) -> V1dCorrelateOutputs:
    """
    1dCorrelate calculates the correlation coefficients between columns of input 1D
    files along with confidence intervals via a bootstrap procedure.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dCorrelate.html
    
    Args:
        input_files: Input 1D files.
        ktaub: Kendall's tau_b correlation (popular somewhere, maybe).
        nboot: Set the number of bootstrap replicates.
        alpha: Set the 2-sided confidence interval width to '100-A' percent.
        blk: Alternate flag for variable-length block resampling.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dCorrelateOutputs`).
    """
    if alpha is not None and not (1 <= alpha <= 20): 
        raise ValueError(f"'alpha' must be between 1 <= x <= 20 but was {alpha}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_CORRELATE_METADATA)
    cargs = []
    cargs.append("1dCorrelate")
    if ktaub:
        cargs.append("-Ktaub")
    if nboot is not None:
        cargs.extend([
            "-nboot",
            str(nboot)
        ])
    if alpha is not None:
        cargs.extend([
            "-alpha",
            str(alpha)
        ])
    if blk:
        cargs.append("-blk")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V1dCorrelateOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dCorrelateOutputs",
    "V_1D_CORRELATE_METADATA",
    "v_1d_correlate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_BINARIZE_METADATA = Metadata(
    id="5a17786daecf5b4f2b98046ba560ad683943319d.boutiques",
    name="mri_binarize",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriBinarizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_binarize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    binary_file_outfile: OutputPathType
    """Binarized output volume."""


def mri_binarize(
    binary_file: InputPathType,
    in_file: InputPathType,
    abs_: bool = False,
    bin_col_num: bool = False,
    bin_val: int | None = None,
    bin_val_not: int | None = None,
    count_file_2: InputPathType | None = None,
    dilate: int | None = None,
    erode: int | None = None,
    erode2d: int | None = None,
    frame_no: int | None = None,
    invert: bool = False,
    mask_file: InputPathType | None = None,
    mask_thresh: float | None = None,
    match: list[int] | None = None,
    max_: float | None = None,
    merge_file: InputPathType | None = None,
    min_: float | None = None,
    out_type: typing.Literal["nii", "nii.gz", "mgz"] | None = None,
    rmax: float | None = None,
    rmin: float | None = None,
    subjects_dir: InputPathType | None = None,
    ventricles: bool = False,
    wm: bool = False,
    wm_ven_csf: bool = False,
    zero_edges: bool = False,
    zero_slice_edge: bool = False,
    runner: Runner | None = None,
) -> MriBinarizeOutputs:
    """
    Program to binarize a volume (or volume-encoded surface file). Can also be used
    to merge with other binarizations. Binarization can be done based on threshold
    or on matched values.
    
    Author: Members of the Laboratories for Computational Neuroimaging (LCN) at
    the Athinoula A. Martinos Center for Biomedical Imaging
    
    URL: https://surfer.nmr.mgh.harvard.edu/fswiki/mri_binarize
    
    Args:
        binary_file: Binary output volume.
        in_file: Input volume.
        abs_: Take abs of invol first (ie, make unsigned).
        bin_col_num: Set binarized voxel value to its column number.
        bin_val: Set vox within thresh to val (default is 1).
        bin_val_not: Set vox outside range to val (default is 0).
        count_file_2: A boolean or file. Save number of hits in ascii file\
            (hits, ntotvox, pct).
        dilate: Niters: dilate binarization in 3d.
        erode: Nerode: erode binarization in 3d (after any dilation).
        erode2d: Nerode2d: erode binarization in 2d (after any 3d erosion).
        frame_no: Use 0-based frame of input (default is 0).
        invert: Set binval=0, binvalnot=1.
        mask_file: Must be within mask.
        mask_thresh: Set thresh for mask.
        match: Match instead of threshold.
        max_: Max thresh.
        merge_file: Merge with mergevol.
        min_: Min thresh.
        out_type: 'nii' or 'nii.gz' or 'mgz'. Output file type.
        rmax: Compute max based on rmax*globalmean.
        rmin: Compute min based on rmin*globalmean.
        subjects_dir: file or string representing an existing directory.\
            Subjects directory.
        ventricles: Set match vals those for aseg ventricles+choroid (not 4th).
        wm: Set match vals to 2 and 41 (aseg for cerebral wm).
        wm_ven_csf: Wm and ventricular csf, including choroid (not 4th).
        zero_edges: Zero the edge voxels.
        zero_slice_edge: Zero the edge slice voxels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriBinarizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_BINARIZE_METADATA)
    cargs = []
    cargs.append("mri_binarize")
    if abs_:
        cargs.append("--abs")
    if bin_col_num:
        cargs.append("--bincol")
    if bin_val is not None:
        cargs.extend([
            "--binval",
            str(bin_val)
        ])
    if bin_val_not is not None:
        cargs.extend([
            "--binvalnot",
            str(bin_val_not)
        ])
    cargs.extend([
        "--o",
        execution.input_file(binary_file)
    ])
    if count_file_2 is not None:
        cargs.extend([
            "--count",
            execution.input_file(count_file_2)
        ])
    if dilate is not None:
        cargs.extend([
            "--dilate",
            str(dilate)
        ])
    if erode is not None:
        cargs.extend([
            "--erode",
            str(erode)
        ])
    if erode2d is not None:
        cargs.extend([
            "--erode2d",
            str(erode2d)
        ])
    if frame_no is not None:
        cargs.extend([
            "--frame",
            str(frame_no)
        ])
    cargs.extend([
        "--i",
        execution.input_file(in_file)
    ])
    if invert:
        cargs.append("--inv")
    if mask_file is not None:
        cargs.extend([
            "--mask maskvol",
            execution.input_file(mask_file)
        ])
    if mask_thresh is not None:
        cargs.extend([
            "--mask-thresh",
            str(mask_thresh)
        ])
    if match is not None:
        cargs.extend([
            "--match",
            *map(str, match)
        ])
    if max_ is not None:
        cargs.extend([
            "--max",
            str(max_)
        ])
    if merge_file is not None:
        cargs.extend([
            "--merge",
            execution.input_file(merge_file)
        ])
    if min_ is not None:
        cargs.extend([
            "--min",
            str(min_)
        ])
    if out_type is not None:
        cargs.append(out_type)
    if rmax is not None:
        cargs.extend([
            "--rmax",
            str(rmax)
        ])
    if rmin is not None:
        cargs.extend([
            "--rmin",
            str(rmin)
        ])
    if subjects_dir is not None:
        cargs.append(execution.input_file(subjects_dir))
    if ventricles:
        cargs.append("--ventricles")
    if wm:
        cargs.append("--wm")
    if wm_ven_csf:
        cargs.append("--wm+vcsf")
    if zero_edges:
        cargs.append("--zero-edges")
    if zero_slice_edge:
        cargs.append("--zero-slice-edges")
    ret = MriBinarizeOutputs(
        root=execution.output_file("."),
        binary_file_outfile=execution.output_file(pathlib.Path(binary_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_BINARIZE_METADATA",
    "MriBinarizeOutputs",
    "mri_binarize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POSSUM_METADATA = Metadata(
    id="833115a38119437ac7f8970c044577f2cf37bc68.boutiques",
    name="possum",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PossumOutputs(typing.NamedTuple):
    """
    Output object returned when calling `possum(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_matrix: OutputPathType
    """Output matrix file generated by possum"""


def possum(
    runner: Runner | None = None,
) -> PossumOutputs:
    """
    Positron emission tomography (PET) simulation tool as part of FSL suite.
    
    Author: University of Oxford (Ivana Drobnjak)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/POSSUM
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PossumOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POSSUM_METADATA)
    cargs = []
    cargs.append("possum")
    cargs.append("-i")
    cargs.append("<input")
    cargs.append("phantom")
    cargs.append("volume>")
    cargs.append("-x")
    cargs.append("<MR")
    cargs.append("parameters")
    cargs.append("matrix>")
    cargs.append("-p")
    cargs.append("<pulse>")
    cargs.append("-f")
    cargs.append("<RF")
    cargs.append("slice")
    cargs.append("profile>")
    cargs.append("-m")
    cargs.append("<motion")
    cargs.append("file>")
    cargs.append("-o")
    cargs.append("<output")
    cargs.append("signal")
    cargs.append("matrix>")
    cargs.append("[additional")
    cargs.append("options]")
    ret = PossumOutputs(
        root=execution.output_file("."),
        output_matrix=execution.output_file("[OUTPUT_MATRIX].mat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POSSUM_METADATA",
    "PossumOutputs",
    "possum",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_JSON_VALUE_PY_METADATA = Metadata(
    id="b47495fb5ed30256cde903666f72bd8e6155f2a1.boutiques",
    name="@djunct_json_value.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunctJsonValuePyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_json_value_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    modified_json_file: OutputPathType
    """Modified JSON file"""


def v__djunct_json_value_py(
    json_file: InputPathType,
    key: str,
    value: str,
    runner: Runner | None = None,
) -> VDjunctJsonValuePyOutputs:
    """
    A supplementary tool for manipulating JSON values in conjunction with AFNI's
    apqc_py.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@djunct_json_value.py.html
    
    Args:
        json_file: Input JSON file.
        key: Key in the JSON object to be modified.
        value: Value to be set for the given key.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunctJsonValuePyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_JSON_VALUE_PY_METADATA)
    cargs = []
    cargs.append("adjunct_json_value")
    cargs.append(execution.input_file(json_file))
    cargs.append(key)
    cargs.append(value)
    ret = VDjunctJsonValuePyOutputs(
        root=execution.output_file("."),
        modified_json_file=execution.output_file(pathlib.Path(json_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunctJsonValuePyOutputs",
    "V__DJUNCT_JSON_VALUE_PY_METADATA",
    "v__djunct_json_value_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPLIT_METADATA = Metadata(
    id="c85abecb56c7b01609f60d0813416382f2f08e43.boutiques",
    name="split",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SplitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `split(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_folder: OutputPathType
    """Output folder with multiple files."""


def split(
    in_file: InputPathType,
    out_base_name: str | None = None,
    dimension: typing.Literal["t", "x", "y", "z"] = "t",
    runner: Runner | None = None,
) -> SplitOutputs:
    """
    split a 4D file into lots of 3D files (eg for inputting to SPM).
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        in_file: Input image to split along dimension (default: time).
        out_base_name: Output prefix.
        dimension: 't' or 'x' or 'y' or 'z'. Dimension to mean across.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SplitOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPLIT_METADATA)
    cargs = []
    cargs.append("fslsplit")
    cargs.append(execution.input_file(in_file))
    if out_base_name is not None:
        cargs.append("out/" + out_base_name)
    cargs.append("-" + dimension)
    ret = SplitOutputs(
        root=execution.output_file("."),
        out_folder=execution.output_file("out/"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPLIT_METADATA",
    "SplitOutputs",
    "split",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BALLOON_METADATA = Metadata(
    id="620bcacf21b1e78ebeb89d8125cf748ada8652bf.boutiques",
    name="balloon",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class BalloonOutputs(typing.NamedTuple):
    """
    Output object returned when calling `balloon(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def balloon(
    tr: float,
    num_scans: int,
    event_times: InputPathType,
    t_fall: list[float] | None = None,
    runner: Runner | None = None,
) -> BalloonOutputs:
    """
    Simulation of haemodynamic response using the balloon model. Based on the
    theoretical model proposed by Buxton et al. (1998).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/balloon.html
    
    Args:
        tr: Scan repetition time in seconds (TR), the interval at which the\
            output curve will be sampled.
        num_scans: Number of scans (N), the output curve will comprise this\
            number of samples.
        event_times: The name of a file containing the event timings, in\
            seconds, as ASCII strings separated by white space, with time 0 being\
            the time at which the initial scan occurred.
        t_fall: Haemodynamic fall time in seconds (typically between 4s and\
            6s).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BalloonOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BALLOON_METADATA)
    cargs = []
    cargs.append("balloon")
    cargs.append(str(tr))
    cargs.append(str(num_scans))
    cargs.append(execution.input_file(event_times))
    if t_fall is not None:
        cargs.extend(map(str, t_fall))
    ret = BalloonOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BALLOON_METADATA",
    "BalloonOutputs",
    "balloon",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DTRANSPOSE_METADATA = Metadata(
    id="fc94a17e9915d6fe592d2778f8c12462cf246455.boutiques",
    name="1dtranspose",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dtransposeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dtranspose(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType | None
    """Transposed output file"""


def v_1dtranspose(
    infile: InputPathType,
    outfile: str | None = None,
    runner: Runner | None = None,
) -> V1dtransposeOutputs:
    """
    Transpose an AFNI *.1D file (ASCII list of numbers arranged in columns).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dtranspose.html
    
    Args:
        infile: Input file (e.g. data.1D).
        outfile: Output file (e.g. transposed_data.1D), or '-' to write to\
            stdout.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dtransposeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DTRANSPOSE_METADATA)
    cargs = []
    cargs.append("1dtranspose")
    cargs.append(execution.input_file(infile))
    if outfile is not None:
        cargs.append(outfile)
    ret = V1dtransposeOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(outfile) if (outfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dtransposeOutputs",
    "V_1DTRANSPOSE_METADATA",
    "v_1dtranspose",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_PREPARE_FIELDMAP_METADATA = Metadata(
    id="6b22511c0f991a159ff6fb3ceff68a57bc1d3fe6.boutiques",
    name="fsl_prepare_fieldmap",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslPrepareFieldmapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_prepare_fieldmap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_fieldmap: OutputPathType
    """The output fieldmap in rad/s format"""


def fsl_prepare_fieldmap(
    scanner: str,
    phase_image: InputPathType,
    magnitude_image: InputPathType,
    out_image: str,
    delta_te: float,
    nocheck_flag: bool = False,
    runner: Runner | None = None,
) -> FslPrepareFieldmapOutputs:
    """
    Prepares a fieldmap suitable for FEAT from SIEMENS data and saves output in
    rad/s format.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/PrepareFieldmap
    
    Args:
        scanner: Scanner type (must be SIEMENS).
        phase_image: Phase image file.
        magnitude_image: Magnitude image file (should be Brain Extracted).
        out_image: Output fieldmap image file.
        delta_te: Echo time difference of the fieldmap sequence in milliseconds.
        nocheck_flag: Suppress automatic sanity checking of image\
            size/range/dimensions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslPrepareFieldmapOutputs`).
    """
    if not (0 <= delta_te): 
        raise ValueError(f"'delta_te' must be greater than 0 <= x but was {delta_te}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_PREPARE_FIELDMAP_METADATA)
    cargs = []
    cargs.append("fsl_prepare_fieldmap")
    cargs.append(scanner)
    cargs.append(execution.input_file(phase_image))
    cargs.append(execution.input_file(magnitude_image))
    cargs.append(out_image)
    cargs.append(str(delta_te))
    if nocheck_flag:
        cargs.append("--nocheck")
    ret = FslPrepareFieldmapOutputs(
        root=execution.output_file("."),
        output_fieldmap=execution.output_file(out_image + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_PREPARE_FIELDMAP_METADATA",
    "FslPrepareFieldmapOutputs",
    "fsl_prepare_fieldmap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POSSUM_PLOT_PY_METADATA = Metadata(
    id="3717e1750050dd9a445255662bf87c6292cddaf5.boutiques",
    name="possum_plot.py",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PossumPlotPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `possum_plot_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_plots: OutputPathType
    """Output plot images from POSSUM"""


def possum_plot_py(
    input_file: InputPathType,
    output_basename: str,
    runner: Runner | None = None,
) -> PossumPlotPyOutputs:
    """
    Tool for plotting results from POSSUM simulations in FSL.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/POSSUM
    
    Args:
        input_file: Input file from POSSUM simulation (e.g.\
            simulation_results.txt).
        output_basename: Basename for output files (e.g. plot_output).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PossumPlotPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POSSUM_PLOT_PY_METADATA)
    cargs = []
    cargs.append("/usr/local/fsl/bin/possum_plot.py")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_basename)
    ret = PossumPlotPyOutputs(
        root=execution.output_file("."),
        output_plots=execution.output_file(output_basename + "_*.png"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POSSUM_PLOT_PY_METADATA",
    "PossumPlotPyOutputs",
    "possum_plot_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_PYTHON_WRAPPER_PY_METADATA = Metadata(
    id="6e37d281f01fec906968b21057c716629cd8edc8.boutiques",
    name="afni_python_wrapper.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniPythonWrapperPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_python_wrapper_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_python_wrapper_py(
    runner: Runner | None = None,
) -> AfniPythonWrapperPyOutputs:
    """
    Python wrapper to call AFNI functions from the shell.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/afni_python_wrapper.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniPythonWrapperPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_PYTHON_WRAPPER_PY_METADATA)
    cargs = []
    cargs.append("afni_python_wrapper.py")
    cargs.append("[FLAGS]")
    cargs.append("[ARGUMENTS]")
    ret = AfniPythonWrapperPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_PYTHON_WRAPPER_PY_METADATA",
    "AfniPythonWrapperPyOutputs",
    "afni_python_wrapper_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__THICKNESS_MASTER_METADATA = Metadata(
    id="20b162e688278463f4b5c90904b0af9c799c8222.boutiques",
    name="@thickness_master",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VThicknessMasterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__thickness_master(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_bb_dir: OutputPathType | None
    """Output directory for ball and box method"""
    output_erode_dir: OutputPathType | None
    """Output directory for erosion method"""
    output_in2out_dir: OutputPathType | None
    """Output directory for in2out method"""


def v__thickness_master(
    maskset: InputPathType,
    surfset: InputPathType,
    outdir: str | None = None,
    runner: Runner | None = None,
) -> VThicknessMasterOutputs:
    """
    Compute cortical thickness using mask and surface datasets.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@thickness_master.html
    
    Args:
        maskset: Mask dataset to find thickness.
        surfset: Surface dataset to use for normals into the volume.
        outdir: Output directory base name. The output will be placed in a\
            directory with thick_base in its name (e.g., mmmm_bb, mmmm_erode,\
            mmmm_in2out).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VThicknessMasterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__THICKNESS_MASTER_METADATA)
    cargs = []
    cargs.append("@thickness_master")
    cargs.append("-maskset")
    cargs.append(execution.input_file(maskset))
    cargs.append("-surfset")
    cargs.append(execution.input_file(surfset))
    cargs.append("-outdir")
    if outdir is not None:
        cargs.append(outdir)
    ret = VThicknessMasterOutputs(
        root=execution.output_file("."),
        output_bb_dir=execution.output_file(outdir + "_bb/") if (outdir is not None) else None,
        output_erode_dir=execution.output_file(outdir + "_erode/") if (outdir is not None) else None,
        output_in2out_dir=execution.output_file(outdir + "_in2out/") if (outdir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VThicknessMasterOutputs",
    "V__THICKNESS_MASTER_METADATA",
    "v__thickness_master",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DICOM_HINFO_METADATA = Metadata(
    id="5ea1bb33f7ee89c2be57f4fd42ad48d1af53ccde.boutiques",
    name="dicom_hinfo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DicomHinfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dicom_hinfo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dicom_hinfo(
    tag: list[str],
    sepstr: str | None = None,
    full_entry: bool = False,
    no_name: bool = False,
    namelast: bool = False,
    runner: Runner | None = None,
) -> DicomHinfoOutputs:
    """
    Prints selected information from one or more DICOM files to stdout.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/dicom_hinfo.html
    
    Args:
        tag: Specify one or more DICOM tags to print, in the format aaaa,bbbb\
            where aaaa and bbbb are hexadecimal digits.
        sepstr: Use the specified string to separate fields instead of space.
        full_entry: Output the full entry if it is more than one word or\
            contains white space.
        no_name: Omit the filename from the output.
        namelast: Place the filename last in the output instead of first.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DicomHinfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DICOM_HINFO_METADATA)
    cargs = []
    cargs.append("dicom_hinfo")
    cargs.extend([
        "-tag",
        *tag
    ])
    if sepstr is not None:
        cargs.extend([
            "-sepstr",
            sepstr
        ])
    if full_entry:
        cargs.append("-full_entry")
    if no_name:
        cargs.append("-no_name")
    if namelast:
        cargs.append("-namelast")
    cargs.append("[FILES...]")
    ret = DicomHinfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DICOM_HINFO_METADATA",
    "DicomHinfoOutputs",
    "dicom_hinfo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__FAST_ROI_METADATA = Metadata(
    id="d82e70f9b79282b8ff3c6e78d4cd767916e2773a.boutiques",
    name="@fast_roi",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VFastRoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__fast_roi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    roi_output: OutputPathType
    """ROI output volume with the specified prefix."""


def v__fast_roi(
    region: list[str],
    anat: InputPathType,
    base: InputPathType,
    roi_grid: InputPathType,
    prefix: str,
    drawn_roi: InputPathType | None = None,
    anat_ns: InputPathType | None = None,
    time_: bool = False,
    twopass: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> VFastRoiOutputs:
    """
    Creates Atlas-based ROI masked in ANAT's original space. The script executes
    rapidly for realtime fMRI applications.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@fast_roi.html
    
    Args:
        region: Symbolic atlas-based region name. Use repeated instances to\
            specify a mask of numerous regions. Each region is assigned a power of\
            2 integer in the output mask.
        anat: ANAT is the volume to be put in standard space. If ANAT is\
            already in TLRC space, there is no need for -base option.
        base: Name of the reference TLRC volume.
        roi_grid: The volume that defines the final ROI's grid.
        prefix: Prefix used to tag the names the ROIs output.
        drawn_roi: A user drawn ROI in standard (tlrc) space. This ROI gets\
            added with the REGION ROI.
        anat_ns: Same as -anat, but indicates that the skull has been removed\
            already.
        time_: Output elapsed time reports.
        twopass: Make TLRC transformation more robust. Use it if TLRC transform\
            step fails.
        help_: Output help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VFastRoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__FAST_ROI_METADATA)
    cargs = []
    cargs.append("fast_roi")
    cargs.extend([
        "-region",
        *region
    ])
    if drawn_roi is not None:
        cargs.extend([
            "-drawn_roi",
            execution.input_file(drawn_roi)
        ])
    cargs.extend([
        "-anat",
        execution.input_file(anat)
    ])
    if anat_ns is not None:
        cargs.extend([
            "-anat_ns",
            execution.input_file(anat_ns)
        ])
    cargs.extend([
        "-base",
        execution.input_file(base)
    ])
    cargs.extend([
        "-roi_grid",
        execution.input_file(roi_grid)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if time_:
        cargs.append("--time")
    if twopass:
        cargs.append("--twopass")
    if help_:
        cargs.append("--help")
    ret = VFastRoiOutputs(
        root=execution.output_file("."),
        roi_output=execution.output_file("ROI." + prefix + "+orig"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VFastRoiOutputs",
    "V__FAST_ROI_METADATA",
    "v__fast_roi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MATCH_METADATA = Metadata(
    id="776b6479db1702d65ad4f7fa5e0459ec4fc1c302.boutiques",
    name="3dMatch",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMatchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_match(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    ref_brik: OutputPathType
    """AFNI BRIK file with the same number of subbricks as the refset file, with
    highest weighted correlation."""
    ref_coeff_vals: OutputPathType
    """Text file recording original indices and coefficients."""
    in_brik: OutputPathType
    """AFNI BRIK file with the same number of subbricks as the inset file, with
    highest weighted correlation."""
    in_coeff_vals: OutputPathType
    """Text file recording original indices and coefficients."""


def v_3d_match(
    inset: InputPathType,
    refset: InputPathType,
    prefix: str,
    mask: InputPathType | None = None,
    in_min: float | None = None,
    in_max: float | None = None,
    ref_min: float | None = None,
    ref_max: float | None = None,
    only_dice_thr: bool = False,
    runner: Runner | None = None,
) -> V3dMatchOutputs:
    """
    Find similar subbricks and rearrange order to ease comparison. Part of FATCAT in
    AFNI.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMatch.html
    
    Args:
        inset: File with M subbricks of data to match against another file.
        refset: File with N subbricks, serving as a reference for INPUT_FILE.
        prefix: Prefix for output name for BRIK/HEAD files and *_coeff.vals\
            text files.
        mask: A mask of regions to include in the correlation of datasets.
        in_min: Threshold below which values in INPUT_FILE will be zeroed\
            during analysis.
        in_max: Threshold above which values in INPUT_FILE will be zeroed\
            during analysis.
        ref_min: Threshold below which values in REF_FILE will be zeroed during\
            analysis.
        ref_max: Threshold above which values in REF_FILE will be zeroed during\
            analysis.
        only_dice_thr: Apply thresholding only during Dice evaluation, not\
            during spatial correlation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMatchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MATCH_METADATA)
    cargs = []
    cargs.append("3dMatch")
    cargs.extend([
        "-inset",
        execution.input_file(inset)
    ])
    cargs.extend([
        "-refset",
        execution.input_file(refset)
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if in_min is not None:
        cargs.extend([
            "-in_min",
            str(in_min)
        ])
    if in_max is not None:
        cargs.extend([
            "-in_max",
            str(in_max)
        ])
    if ref_min is not None:
        cargs.extend([
            "-ref_min",
            str(ref_min)
        ])
    if ref_max is not None:
        cargs.extend([
            "-ref_max",
            str(ref_max)
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if only_dice_thr:
        cargs.append("-only_dice_thr")
    ret = V3dMatchOutputs(
        root=execution.output_file("."),
        ref_brik=execution.output_file(prefix + "_REF+orig.BRIK"),
        ref_coeff_vals=execution.output_file(prefix + "_REF_coeff.vals"),
        in_brik=execution.output_file(prefix + "_IN+orig.BRIK"),
        in_coeff_vals=execution.output_file(prefix + "_IN_coeff.vals"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMatchOutputs",
    "V_3D_MATCH_METADATA",
    "v_3d_match",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DNORM_METADATA = Metadata(
    id="ca9071bf1196c49108dfaa8149e0784b241bd37a.boutiques",
    name="1dnorm",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dnormOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dnorm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    normalized_output: OutputPathType
    """Normalized output AFNI *.1D file"""


def v_1dnorm(
    infile: InputPathType,
    outfile: str,
    runner: Runner | None = None,
) -> V1dnormOutputs:
    """
    Normalize columns of a 1D file (AFNI ASCII list of numbers).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dnorm.html
    
    Args:
        infile: Input AFNI *.1D file (ASCII list of numbers arranged in\
            columns); if '-' input will be read from stdin.
        outfile: Output AFNI *.1D file (normalized); if '-' output will be\
            written to stdout.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dnormOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DNORM_METADATA)
    cargs = []
    cargs.append("1dnorm")
    cargs.append("[OPTION]")
    cargs.append(execution.input_file(infile))
    cargs.append(outfile)
    ret = V1dnormOutputs(
        root=execution.output_file("."),
        normalized_output=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dnormOutputs",
    "V_1DNORM_METADATA",
    "v_1dnorm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_XCLUST_SIM_METADATA = Metadata(
    id="56860ad5ffbaa0bd9bb33e1b03cac2b121ed79ff.boutiques",
    name="3dXClustSim",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dXclustSimOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_xclust_sim(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_mthresh: OutputPathType | None
    """Output multi-threshold files for each -ncase input"""


def v_3d_xclust_sim(
    inset: InputPathType,
    insdat: InputPathType | None = None,
    nn: float | None = None,
    sid: float | None = None,
    hpow: list[float] | None = None,
    ncase: list[str] | None = None,
    pthr: list[float] | None = None,
    fpr: float | None = None,
    multi_fpr: bool = False,
    minclust: float | None = None,
    local: bool = False,
    global_: bool = False,
    nolocal: bool = False,
    noglobal: bool = False,
    splitfrac: float | None = None,
    prefix: str | None = None,
    verbose: bool = False,
    quiet: bool = False,
    runner: Runner | None = None,
) -> V3dXclustSimOutputs:
    """
    ETAC processing tool to find cluster figure of merit (FOM) thresholds.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dXClustSim.html
    
    Args:
        inset: Mask sdata file (from 3dtoXdataset or 3dttest++).
        insdat: Data files in the '.sdat' format.
        nn: Neighborhood connectivity (1, 2, or 3). Default is 2.
        sid: Sidedness: 1 (one-sided) or 2 (two-sided). Default is 2.
        hpow: H power values (can be a subset of 0, 1, 2). Default is 2.
        ncase: Number of cases with labels. Default is 1 A.
        pthr: List of p-value thresholds. Default is 0.0100 0.0056 0.0031\
            0.0018 0.0010.
        fpr: Set global FPR goal to an integer ff between 2 and 9. Default is\
            5.
        multi_fpr: Compute results for multiple FPR goals (2%, 3%, ... 9%).
        minclust: Minimum cluster size in voxels. Default is 5.
        local: Do voxel-wise (local) ETAC computations.
        global_: Do volume-wise (global) ETAC computations.
        nolocal: Do not perform voxel-wise ETAC computations.
        noglobal: Do not perform volume-wise ETAC computations.
        splitfrac: Fraction to split simulations into pieces (0.2 < F < 0.8).
        prefix: Output filename prefix.
        verbose: Be more verbose.
        quiet: Silent mode.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dXclustSimOutputs`).
    """
    if fpr is not None and not (2 <= fpr <= 9): 
        raise ValueError(f"'fpr' must be between 2 <= x <= 9 but was {fpr}")
    if splitfrac is not None and not (0.2 <= splitfrac <= 0.8): 
        raise ValueError(f"'splitfrac' must be between 0.2 <= x <= 0.8 but was {splitfrac}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_XCLUST_SIM_METADATA)
    cargs = []
    cargs.append("3dXClustSim")
    cargs.append(execution.input_file(inset))
    if insdat is not None:
        cargs.append(execution.input_file(insdat))
    if nn is not None:
        cargs.extend([
            "-NN",
            str(nn)
        ])
    if sid is not None:
        cargs.extend([
            "-sid",
            str(sid)
        ])
    if hpow is not None:
        cargs.extend([
            "-hpow",
            *map(str, hpow)
        ])
    if ncase is not None:
        cargs.extend([
            "-ncase",
            *ncase
        ])
    if pthr is not None:
        cargs.extend([
            "-pthr",
            *map(str, pthr)
        ])
    if fpr is not None:
        cargs.extend([
            "-FPR",
            str(fpr)
        ])
    if multi_fpr:
        cargs.append("-multiFPR")
    if minclust is not None:
        cargs.extend([
            "-minclust",
            str(minclust)
        ])
    if local:
        cargs.append("-local")
    if global_:
        cargs.append("-global")
    if nolocal:
        cargs.append("-nolocal")
    if noglobal:
        cargs.append("-noglobal")
    if splitfrac is not None:
        cargs.extend([
            "-splitfrac",
            str(splitfrac)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if verbose:
        cargs.append("-verb")
    if quiet:
        cargs.append("-quiet")
    ret = V3dXclustSimOutputs(
        root=execution.output_file("."),
        out_mthresh=execution.output_file(prefix + ".mthresh.*.nii") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dXclustSimOutputs",
    "V_3D_XCLUST_SIM_METADATA",
    "v_3d_xclust_sim",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GEN_SS_REVIEW_SCRIPTS_PY_METADATA = Metadata(
    id="80b9c54f813723060d1c958720d386d625adb79a.boutiques",
    name="gen_ss_review_scripts.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GenSsReviewScriptsPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gen_ss_review_scripts_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    basic_review: OutputPathType
    """Basic review script output"""
    driver_review: OutputPathType
    """Driver review script output"""
    driver_commands: OutputPathType
    """Driver commands script output"""


def gen_ss_review_scripts_py(
    runner: Runner | None = None,
) -> GenSsReviewScriptsPyOutputs:
    """
    Generate single subject analysis review scripts.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/gen_ss_review_scripts.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GenSsReviewScriptsPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GEN_SS_REVIEW_SCRIPTS_PY_METADATA)
    cargs = []
    cargs.append("gen_ss_review_scripts.py")
    cargs.append("[INPUT_FILES]")
    cargs.append("[OPTIONS]")
    ret = GenSsReviewScriptsPyOutputs(
        root=execution.output_file("."),
        basic_review=execution.output_file("./@ss_review_basic"),
        driver_review=execution.output_file("./@ss_review_driver"),
        driver_commands=execution.output_file("./@ss_review_driver_commands"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GEN_SS_REVIEW_SCRIPTS_PY_METADATA",
    "GenSsReviewScriptsPyOutputs",
    "gen_ss_review_scripts_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANATOMICAL_AVERAGE_METADATA = Metadata(
    id="4d1ca27f9d946d87c62899d1b8d9e62d2557220d.boutiques",
    name="AnatomicalAverage",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class AnatomicalAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `anatomical_average(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    avg_output: OutputPathType
    """Averaged anatomical image"""


def anatomical_average(
    output_basename: str,
    input_images: list[InputPathType],
    runner: Runner | None = None,
) -> AnatomicalAverageOutputs:
    """
    Tool to create an anatomical average of input brain images.
    
    Author: Brain Imaging Center
    
    URL: https://example.com/anatomicalaverage
    
    Args:
        output_basename: Output basename.
        input_images: List of input images.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AnatomicalAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANATOMICAL_AVERAGE_METADATA)
    cargs = []
    cargs.append("AnatomicalAverage")
    cargs.append("[OPTIONAL_ARGS]")
    cargs.append("-o")
    cargs.extend([
        "-o",
        output_basename
    ])
    cargs.extend([execution.input_file(f) for f in input_images])
    ret = AnatomicalAverageOutputs(
        root=execution.output_file("."),
        avg_output=execution.output_file(output_basename + "_avg.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANATOMICAL_AVERAGE_METADATA",
    "AnatomicalAverageOutputs",
    "anatomical_average",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMREG_METADATA = Metadata(
    id="9eb7e2d86ad67ffd9b28c2a3619d573a48d1975b.boutiques",
    name="imreg",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_images: OutputPathType | None
    """Registered images"""
    dx_file: OutputPathType | None
    """Time series dx file"""
    dy_file: OutputPathType | None
    """Time series dy file"""
    phi_file: OutputPathType | None
    """Time series phi file"""


def imreg(
    base_image: str,
    image_sequence: list[InputPathType],
    nowrite: bool = False,
    prefix: str | None = None,
    suffix: str | None = None,
    start: float | None = None,
    step: float | None = None,
    flim: bool = False,
    keepsize: bool = False,
    quiet: bool = False,
    debug: bool = False,
    dprefix: str | None = None,
    bilinear: bool = False,
    modes: str | None = None,
    mlcf: bool = False,
    wtim: InputPathType | None = None,
    dfspace: bool = False,
    cmass: bool = False,
    fine: list[float] | None = None,
    nofine: bool = False,
    runner: Runner | None = None,
) -> ImregOutputs:
    """
    Registers each 2D image in 'image_sequence' to 'base_image'.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/imreg.html
    
    Args:
        base_image: Base image or method to determine base image ('+AVER' or\
            '+count').
        image_sequence: Sequence of images to be registered.
        nowrite: Don't write outputs, just print progress reports.
        prefix: Prefix for output file names.
        suffix: Suffix for output file names.
        start: Start index for output file names.
        step: Step size for output file indices.
        flim: Write output in mrilib floating point format.
        keepsize: Preserve the original image size on output.
        quiet: Don't write progress report messages.
        debug: Write lots of debugging output.
        dprefix: Prefix for dx, dy, and phi files.
        bilinear: Use bilinear interpolation.
        modes: Interpolation modes during coarse, fine, and registration phases.
        mlcf: Equivalent to '-modes bilinear bicubic Fourier'.
        wtim: Weighting image file.
        dfspace: Use difiterated differential spatial method.
        cmass: Align centers of mass of the images.
        fine: Fine fit parameters: blur, dxy, dphi.
        nofine: Turn off the 'fine' fit algorithm.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMREG_METADATA)
    cargs = []
    cargs.append("imreg")
    cargs.append(base_image)
    cargs.extend([execution.input_file(f) for f in image_sequence])
    if nowrite:
        cargs.append("-nowrite")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if suffix is not None:
        cargs.extend([
            "-suffix",
            suffix
        ])
    if start is not None:
        cargs.extend([
            "-start",
            str(start)
        ])
    if step is not None:
        cargs.extend([
            "-step",
            str(step)
        ])
    if flim:
        cargs.append("-flim")
    if keepsize:
        cargs.append("-keepsize")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if dprefix is not None:
        cargs.extend([
            "-dprefix",
            dprefix
        ])
    if bilinear:
        cargs.append("-bilinear")
    if modes is not None:
        cargs.extend([
            "-modes",
            modes
        ])
    if mlcf:
        cargs.append("-mlcF")
    if wtim is not None:
        cargs.extend([
            "-wtim",
            execution.input_file(wtim)
        ])
    if dfspace:
        cargs.append("-dfspace")
    if cmass:
        cargs.append("-cmass")
    if fine is not None:
        cargs.extend([
            "-fine",
            *map(str, fine)
        ])
    if nofine:
        cargs.append("-nofine")
    ret = ImregOutputs(
        root=execution.output_file("."),
        registered_images=execution.output_file(prefix + ".[INDEX]." + suffix) if (prefix is not None and suffix is not None) else None,
        dx_file=execution.output_file(dprefix + ".dx") if (dprefix is not None) else None,
        dy_file=execution.output_file(dprefix + ".dy") if (dprefix is not None) else None,
        phi_file=execution.output_file(dprefix + ".phi") if (dprefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMREG_METADATA",
    "ImregOutputs",
    "imreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DGRAYPLOT_METADATA = Metadata(
    id="89e4649907a2a1854a7fce55508f9096cc0c7563.boutiques",
    name="1dgrayplot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dgrayplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dgrayplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1dgrayplot(
    tsfile: InputPathType,
    runner: Runner | None = None,
) -> V1dgrayplotOutputs:
    """
    Graphs the columns of a *.1D type time series file to the screen in grayscale.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dgrayplot.html
    
    Args:
        tsfile: Input time series file (*.1D format).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dgrayplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DGRAYPLOT_METADATA)
    cargs = []
    cargs.append("1dgrayplot")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(tsfile))
    ret = V1dgrayplotOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dgrayplotOutputs",
    "V_1DGRAYPLOT_METADATA",
    "v_1dgrayplot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TOPUP_METADATA = Metadata(
    id="d2018874d8c39fcdb4d692dff1529e2ea871e2a5.boutiques",
    name="topup",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class TopupOutputs(typing.NamedTuple):
    """
    Output object returned when calling `topup(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fieldcoef: OutputPathType | None
    """Spline coefficient field estimates (Hz)"""
    movpar: OutputPathType | None
    """Movement parameters"""
    fout: OutputPathType | None
    """Image file with field (Hz)"""
    iout: OutputPathType | None
    """4D image file with unwarped images"""
    logout: OutputPathType | None
    """Log file"""


def topup(
    imain: InputPathType,
    datain: InputPathType,
    out: str | None = None,
    fout: str | None = None,
    iout: str | None = None,
    logout: str | None = None,
    warpres: float | None = None,
    subsamp: float | None = None,
    fwhm: float | None = None,
    config: InputPathType | None = None,
    miter: float | None = None,
    lambda_: float | None = None,
    ssqlambda: bool = False,
    regmod: typing.Literal["membrane_energy", "bending_energy"] | None = None,
    estmov: bool = False,
    minmet: typing.Literal[0, 1] | None = None,
    splineorder: typing.Literal[2, 3] | None = None,
    numprec: typing.Literal["double", "float"] | None = None,
    interp: typing.Literal["linear", "spline"] | None = None,
    scale: bool = False,
    regrid: bool = False,
    nthr: float | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> TopupOutputs:
    """
    topup is part of FSL and is used to estimate and correct for
    susceptibility-induced distortions in echo planar imaging (EPI) data.
    
    Author: University of Oxford
    
    Args:
        imain: Name of 4D file with images.
        datain: Name of text file with PE directions/times.
        out: Base-name of output files (spline coefficients (Hz) and movement\
            parameters).
        fout: Name of image file with field (Hz).
        iout: Name of 4D image file with unwarped images.
        logout: Name of log-file.
        warpres: (Approximate) resolution (in mm) of warp basis for the\
            different sub-sampling levels, default 10.
        subsamp: Sub-sampling scheme, default 1.
        fwhm: FWHM (in mm) of gaussian smoothing kernel, default 8.
        config: Name of config file specifying command line arguments.
        miter: Max # of non-linear iterations, default 5.
        lambda_: Weight of regularisation, default depending on --ssqlambda and\
            --regmod switches. See user documentation.
        ssqlambda: If set (=1), lambda is weighted by current ssq, default 1.
        regmod: Model for regularisation of warp-field [membrane_energy\
            bending_energy], default bending_energy.
        estmov: Estimate movements if set, default 1 (true).
        minmet: Minimisation method 0=Levenberg-Marquardt, 1=Scaled Conjugate\
            Gradient, default 0 (LM).
        splineorder: Order of spline, 2=Quadratic spline, 3=Cubic spline.\
            Default=3.
        numprec: Precision for representing Hessian, double or float. Default\
            double.
        interp: Image interpolation model, linear or spline. Default spline.
        scale: If set (=1), the images are individually scaled to a common\
            mean, default 0 (false).
        regrid: If set (=1), the calculations are done in a different grid,\
            default 1 (true).
        nthr: Number of threads to use (cannot be greater than numbers of\
            hardware cores), default 1.
        verbose: Print diagnostic information while running.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TopupOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TOPUP_METADATA)
    cargs = []
    cargs.append("topup")
    cargs.append("--imain=" + execution.input_file(imain))
    cargs.append("--datain=" + execution.input_file(datain))
    if out is not None:
        cargs.append("--out=" + out)
    if fout is not None:
        cargs.append("--fout=" + fout)
    if iout is not None:
        cargs.append("--iout=" + iout)
    if logout is not None:
        cargs.append("--logout=" + logout)
    if warpres is not None:
        cargs.append("--warpres=" + str(warpres))
    if subsamp is not None:
        cargs.append("--subsamp=" + str(subsamp))
    if fwhm is not None:
        cargs.append("--fwhm=" + str(fwhm))
    if config is not None:
        cargs.append("--config=" + execution.input_file(config))
    if miter is not None:
        cargs.append("--miter=" + str(miter))
    if lambda_ is not None:
        cargs.append("--lambda=" + str(lambda_))
    if ssqlambda:
        cargs.append("--ssqlambda")
    if regmod is not None:
        cargs.append("--regmod=" + regmod)
    if estmov:
        cargs.append("--estmov")
    if minmet is not None:
        cargs.append("--minmet=" + str(minmet))
    if splineorder is not None:
        cargs.append("--splineorder=" + str(splineorder))
    if numprec is not None:
        cargs.append("--numprec=" + numprec)
    if interp is not None:
        cargs.append("--interp=" + interp)
    if scale:
        cargs.append("--scale")
    if regrid:
        cargs.append("--regrid")
    if nthr is not None:
        cargs.append("--nthr=" + str(nthr))
    if verbose:
        cargs.append("--verbose")
    ret = TopupOutputs(
        root=execution.output_file("."),
        fieldcoef=execution.output_file(out + "_fieldcoef.nii.gz") if (out is not None) else None,
        movpar=execution.output_file(out + "_movpar.txt") if (out is not None) else None,
        fout=execution.output_file(fout) if (fout is not None) else None,
        iout=execution.output_file(iout) if (iout is not None) else None,
        logout=execution.output_file(logout) if (logout is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TOPUP_METADATA",
    "TopupOutputs",
    "topup",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIXELCORRESPONDENCE_METADATA = Metadata(
    id="e504e8529648fd4befb8831d2415e0de7107e1d1.boutiques",
    name="fixelcorrespondence",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class FixelcorrespondenceConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class FixelcorrespondenceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fixelcorrespondence(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fixelcorrespondence(
    subject_data: InputPathType,
    template_directory: InputPathType,
    output_directory: str,
    output_data: str,
    angle: float | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[FixelcorrespondenceConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> FixelcorrespondenceOutputs:
    """
    Obtain fixel-fixel correpondence between a subject fixel image and a template
    fixel mask.
    
    It is assumed that the subject image has already been spatially normalised
    and is aligned with the template. The output fixel image will have the same
    fixels (and directions) of the template.
    
    References:
    
    .
    
    Author: David Raffelt (david.raffelt@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/fixelcorrespondence.html
    
    Args:
        subject_data: the input subject fixel data file. This should be a file\
            inside the fixel directory.
        template_directory: the input template fixel directory.
        output_directory: the fixel directory where the output file will be\
            written.
        output_data: the name of the output fixel data file. This will be\
            placed in the output fixel directory.
        angle: the max angle threshold for computing inter-subject fixel\
            correspondence (Default: 45 degrees).
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixelcorrespondenceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIXELCORRESPONDENCE_METADATA)
    cargs = []
    cargs.append("fixelcorrespondence")
    if angle is not None:
        cargs.extend([
            "-angle",
            str(angle)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(subject_data))
    cargs.append(execution.input_file(template_directory))
    cargs.append(output_directory)
    cargs.append(output_data)
    ret = FixelcorrespondenceOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIXELCORRESPONDENCE_METADATA",
    "FixelcorrespondenceConfig",
    "FixelcorrespondenceOutputs",
    "fixelcorrespondence",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EDDY_CORRECT_METADATA = Metadata(
    id="a10ffaf77e8183d3b1942b8df6692377004eca30.boutiques",
    name="eddy_correct",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class EddyCorrectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `eddy_correct(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_4d_output: OutputPathType
    """Corrected 4D output image file"""


def eddy_correct(
    v_4d_input: InputPathType,
    v_4d_output: str,
    reference_no: int,
    interp_method: typing.Literal["trilinear", "spline"] | None = "trilinear",
    runner: Runner | None = None,
) -> EddyCorrectOutputs:
    """
    Eddy current correction tool for FSL.
    
    Author: FMRIB
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/EDDY
    
    Args:
        v_4d_input: Input 4D image file (e.g., dti.nii.gz).
        v_4d_output: Output 4D image file (e.g., dti_corrected.nii.gz).
        reference_no: Reference number.
        interp_method: Interpolation method to use: 'trilinear' or 'spline'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EddyCorrectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EDDY_CORRECT_METADATA)
    cargs = []
    cargs.append("eddy_correct")
    cargs.append(execution.input_file(v_4d_input))
    cargs.append(v_4d_output)
    cargs.append(str(reference_no))
    if interp_method is not None:
        cargs.append(interp_method)
    ret = EddyCorrectOutputs(
        root=execution.output_file("."),
        corrected_4d_output=execution.output_file(v_4d_output + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EDDY_CORRECT_METADATA",
    "EddyCorrectOutputs",
    "eddy_correct",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ATLASQUERY_METADATA = Metadata(
    id="01942ea09300720e7fb04693272806c8ad89763b.boutiques",
    name="atlasquery",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class AtlasqueryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `atlasquery(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def atlasquery(
    dumpatlases_flag: bool = False,
    atlas: str | None = None,
    coord: str | None = None,
    mask: InputPathType | None = None,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> AtlasqueryOutputs:
    """
    Structural lookup tool for FSL atlases.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Atlasquery
    
    Args:
        dumpatlases_flag: Dump a list of available atlases.
        atlas: Name of atlas to use.
        coord: Coordinate to query in the format X,Y,Z.
        mask: A mask image to use during structural lookups.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Show help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AtlasqueryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ATLASQUERY_METADATA)
    cargs = []
    cargs.append("atlasq")
    cargs.append("ohi")
    if dumpatlases_flag:
        cargs.append("--dumpatlases")
    if atlas is not None:
        cargs.extend([
            "-a",
            atlas
        ])
    if coord is not None:
        cargs.extend([
            "-c",
            coord
        ])
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if verbose_flag:
        cargs.append("-V")
    if help_flag:
        cargs.append("-h")
    ret = AtlasqueryOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ATLASQUERY_METADATA",
    "AtlasqueryOutputs",
    "atlasquery",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UNIQ_IMAGES_METADATA = Metadata(
    id="670d22d3017ad96917743645ee4b5352db443373.boutiques",
    name="uniq_images",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class UniqImagesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `uniq_images(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unique_files_list: OutputPathType
    """Generated list of filenames with unique images"""


def uniq_images(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> UniqImagesOutputs:
    """
    Simple program to read in a list of image filenames, determine which files have
    unique images inside, and echo out only a list of the filenames with unique
    images.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/uniq_images.html
    
    Args:
        input_files: List of image filenames to be processed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UniqImagesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UNIQ_IMAGES_METADATA)
    cargs = []
    cargs.append("uniq_images")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = UniqImagesOutputs(
        root=execution.output_file("."),
        unique_files_list=execution.output_file("unique_images_list.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UNIQ_IMAGES_METADATA",
    "UniqImagesOutputs",
    "uniq_images",
]
